local BLOODTRADER_NPCID = 115264
local BLOOD_ITEMID = 124124
local BLOOD_ITEMTEXTURE = GetItemIcon(BLOOD_ITEMID)

local function IsBloodTrader()
  local guid = UnitGUID("npc")
  if not guid then return end
  local _, _, _, _, _, npcid = strsplit("-", guid)
  if not npcid then return end
  if tonumber(npcid) ~= BLOODTRADER_NPCID then return end
  return true
end

-- Only buys multiples of vendor stack size. Rounds down unless it's less than vendor stack size
local oldStackSplitFrameOkay_Click = StackSplitOkayButton:GetScript("OnClick")
StackSplitOkayButton:SetScript("OnClick", function()
  -- if blood trader, lower purchase amount to multiple of vendor stack size
  if IsBloodTrader() and StackSplitFrame.owner:GetName():sub(1,12) == "MerchantItem" then
    local _, _, _, stackCount = GetMerchantItemInfo(StackSplitFrame.owner:GetID())

    -- if trying to buy under the stack size, round up to the stack size
    if StackSplitFrame.split < stackCount then
      StackSplitFrame.split = stackCount
    else
      local overage = StackSplitFrame.split % stackCount
      StackSplitFrame.split = StackSplitFrame.split - overage    
    end
  end
  
  oldStackSplitFrameOkay_Click()
end)

-- Hook GetMerchantItemInfo but only when it's called from within
-- FrameXML/MerchantFrame.lua's MerchantItemButton_OnModifiedClick() function
-- This makes the UI think that the Blood Trader only sells stacks of 1 for
-- the purposes of allowing split stacks.
local oldGetMerchantItemInfo = GetMerchantItemInfo
GetMerchantItemInfo = function(index, ...)
  -- ignore if not blood trader
  if not IsBloodTrader() then return oldGetMerchantItemInfo(index, ...) end

  -- get original values
  local name, texture, price, quantity, numAvailable, isUsable, extendedCost = oldGetMerchantItemInfo(index)
  
  -- only change quantity if GetMerchantItemInfo is being called from MerchantItemButton_OnModifiedClick
  local stack = debugstack(2,1,0)
  if stack:match("MerchantItemButton_OnModifiedClick") then quantity = 1 end
  
  -- return values with quantity possibly modified
  return name, texture, price, quantity, numAvailable, isUsable, extendedCost  
end

-- Show blood of sargeras as a currency in lower right of vendor window
hooksecurefunc("MerchantFrame_UpdateCurrencies", function ()
  -- ignore if not blood trader
  if not IsBloodTrader() then return end
  
  -- the following code mimics MerchantFrame_UpdateCurrencies in showing currencies in lower right
  -- except it assumes only 1 will be shown (instead of up to 6), and it uses Item functions instead
  -- of Currency functions
  MerchantExtraCurrencyInset:Show()
  MerchantExtraCurrencyBg:Show()
  MerchantMoneyFrame:SetPoint("BOTTOMRIGHT", -169, 8)
  MerchantMoneyFrame:Show()
  
  local tokenButton = _G["MerchantToken1"]
  -- if this button doesn't exist yet, create it and anchor it
  if ( not tokenButton ) then
    tokenButton = CreateFrame("BUTTON", "MerchantToken1", MerchantFrame, "BackpackTokenTemplate")
    tokenButton:SetPoint("BOTTOMRIGHT", -16, 8)
    tokenButton:SetScript("OnEnter", function(self) GameTooltip:SetOwner(self, "ANCHOR_RIGHT") GameTooltip:SetItemByID(BLOOD_ITEMID) end)
    tokenButton:SetScript("OnClick", function(self, button) if IsModifiedClick("CHATLINK") then HandleModifiedItemClick(select(2, GetItemInfo(BLOOD_ITEMID))) end end)
  end
  
  tokenButton.icon:SetTexture(BLOOD_ITEMTEXTURE)
  tokenButton.count:SetText(GetItemCount(BLOOD_ITEMID, true) or 0)
  tokenButton:Show();
end)

--[[
-- This removes the confirmation when buying items from blood trader
hooksecurefunc("MerchantFrame_UpdateMerchantInfo", function()
  -- ignore if not blood trader
  if not IsBloodTrader() then return end
  
  -- clear extendedCost flag on each button. this causes the purchasing code to skip over
  -- the confirmation in the OnClick handlers and in the OpenSplitStackFrame callbacks
  for i=1, MERCHANT_ITEMS_PER_PAGE, 1 do
    local itemButton = _G["MerchantItem"..i.."ItemButton"]
    if itemButton and itemButton.hasItem then itemButton.extendedCost = nil end
  end
end)
--]]

--[[
-- Returns 198 for max stack size of starlight rose and leylight shard
local oldGetMerchantItemMaxStack = GetMerchantItemMaxStack
GetMerchantItemMaxStack = function(index, ...)
  if IsBloodTrader() and (index == 17 or index == 26) then return 198 end
  
  return oldGetMerchantItemMaxStack(index, ...)  
end
--]]


--[[
-- Makes overflow input in the stack split window set the value to max instead of ignoring it
local oldStackSplitFrame_OnChar = StackSplitFrame:GetScript("OnChar")
StackSplitFrame:SetScript("OnChar", function(self,text)
  if ( text < "0" or text > "9" ) then
    return;
  end

  if ( self.typing == 0 ) then
    self.typing = 1;
    self.split = 0;
  end

  local split = (self.split * 10) + text;
  if ( split == self.split ) then
    if( self.split == 0 ) then
      self.split = 1;
    end
    return;
  end
  
  --if IsBloodTrader() and StackSplitFrame.owner:GetName():sub(1,12) == "MerchantItem" and split > self.maxStack then split = self.maxStack end
  
  if ( split <= self.maxStack ) then
    self.split = split;
    StackSplitText:SetText(split);
    if ( split == self.maxStack ) then
      StackSplitRightButton:Disable();
    else
      StackSplitRightButton:Enable();
    end
    if ( split == 1 ) then
      StackSplitLeftButton:Disable();
    else
      StackSplitLeftButton:Enable();
    end
  elseif ( split == 0 ) then
    self.split = 1;
  end
end)
--]]